@@ -1,7 +1,8 @@
 #!/bin/sh
+export PATH='/usr/obj/hs-async-2.0.1.5/bin:/usr/bin:/bin:/usr/sbin:/sbin:/usr/local/bin:/usr/local/bin:/usr/X11R6/bin'
 echo 'name: async
-version: 2.0.1.4
-id: async-2.0.1.4-3eae4a440b34cbf08aad8765dbd61d40
+version: 2.0.1.5
+id: async-2.0.1.5-d3d04a10c586684bc475e30da2683355
 
 license: BSD3
 copyright: (c) Simon Marlow 2012
@@ -30,6 +31,10 @@ description: This package provides a higher-level interface over
              threads that are automatically killed when
              their parent dies (see '\''withAsync'\'').
              .
+             Changes in 2.0.1.5:
+             .
+             * Bump @base@ dependencies for GHC 7.8
+             .
              Changes in 2.0.1.4:
              .
              * Bump @base@ dependency of test suite
@@ -62,20 +67,20 @@ exposed: True
 exposed-modules: Control.Concurrent.Async
 hidden-modules:
 trusted: False
-import-dirs: /usr/local/lib/ghc/async-2.0.1.4
-library-dirs: /usr/local/lib/ghc/async-2.0.1.4
-hs-libraries: HSasync-2.0.1.4
+import-dirs: /usr/local/lib/ghc/async-2.0.1.5
+library-dirs: /usr/local/lib/ghc/async-2.0.1.5
+hs-libraries: HSasync-2.0.1.5
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: base-4.6.0.1-6b06c3defb20732cfd08deb8ba52ca7c
-         stm-2.4.2-b5d718b1a5f1fbcdb61a336aef0c2130
+depends: base-4.7.0.2-e1c96ce41208f09c293083d78870d5a2
+         stm-2.4.2-23ae3f5d4fc8efd50db962931f6670a1
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-async-2.0.1.4/html/async.haddock
-haddock-html: /usr/local/share/doc/hs-async-2.0.1.4/html
+haddock-interfaces: /usr/local/share/doc/hs-async-2.0.1.5/html/async.haddock
+haddock-html: /usr/local/share/doc/hs-async-2.0.1.5/html
 ' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
